@@ -48,3 +48,20 @@ def make_datetime_from_iso_jdate_time(ist) :
 
 fu0 = make_datetime_from_iso_jdate_time
 vect_make_datetime_from_iso_jdate_time = vectorize(fu0)
+
+def find_jmonth_fr_persian_col_in_df(df , targ_col , new_col , sep = '/') :
+    pat = '(1[34]\d{2}' + sep + '\d{2}' + sep + '\d{2})'
+
+    msk = df[targ_col].notna()
+    _df = df[msk]
+
+    s = _df[targ_col].astype(str)
+    s = s.str.extract(pat)
+    s = s.str.replace('\D' , '')
+    s = s.str[:6]
+    s = s.astype(int)
+    s = s.astype('string')
+    s = s.str[:4] + '-' + s.str[4 :6]
+
+    df.loc[msk , new_col] = s
+    return df
